.. ECG-featurizer documentation master file, created by
   sphinx-quickstart on Thu Nov  5 19:08:14 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ECG-featurizer's documentation!
==========================================


Welcome to **ECG-featurizer**'s documentation. Here you can find information and learn about how to use the package, how to contribute and more



.. toctree::
   :maxdepth: 2

   Get started
   authors
   installation
   contributing
   
